mac80211: report failure to start (partial) scan as scan abort

Rather than reporting the scan as having completed, report it as
being aborted.

Signed-off-by: Johannes Berg <johannes.berg@intel.com>
diff --git a/net/mac80211/scan.c b/net/mac80211/scan.c
index 8d4a9cd..070b40f 100644
--- a/net/mac80211/scan.c
+++ b/net/mac80211/scan.c
@@ -362,10 +362,11 @@
 		if (rc == 0)
 			return;
 
 		/* HW scan failed and is going to be reported as done, so clear
 		 * old scan info.
 		 */
 		memset(&local->scan_info, 0, sizeof(local->scan_info));
+		aborted = true;
 	}
 
 	kfree(local->hw_scan_req);
@@ -362,10 +362,11 @@
 			return;
 
-		/* HW scan failed and is going to be reported as done, so clear
-		 * old scan info.
+		/* HW scan failed and is going to be reported as aborted,
+		 * so clear old scan info.
 		 */
 		memset(&local->scan_info, 0, sizeof(local->scan_info));